Citrix DaaS™

Criar catálogos usando imagens preparadas em instâncias gerenciadas do Amazon WorkSpaces Core

Crie imagens preparadas e use-as para criar um catálogo de máquinas MCS usando:

  • Studio
  • PowerShell

Etapas principais

  1. Crie a definição da imagem e a versão inicial da imagem.
  2. Crie versões de imagem a partir da versão inicial da imagem.
  3. Use a versão da imagem como uma imagem preparada para criar um catálogo.

Crie uma definição de imagem e a versão inicial da imagem usando o Studio

Para criar uma definição de imagem e a versão inicial da imagem, faça o seguinte:

  1. No Studio, vá para o nó Imagens e clique em Criar Definição de Imagem. Clique em Avançar na página Introdução.
  2. Na página Definição de Imagem, especifique o Tipo de SO e o Tipo de Sessão para a definição da imagem.
  3. Na página Imagem, selecione Recursos (somente os recursos aplicáveis para a conexão definida são listados), uma imagem mestre para usar como modelo para criar a versão da imagem e um perfil de máquina para capturar propriedades de hardware. Selecione um perfil de máquina para capturar propriedades de hardware de uma instância de VM ou versão de modelo de inicialização.

    Nota:

    • Antes de selecionar uma imagem, verifique se a imagem mestre tem o VDA 2311 ou posterior instalado e se o driver MCSIO está instalado no VDA.
    • O Serviço de Metadados de Instância (IMDS) V2 é o único suportado, e não o IMDS V1. Para obter informações, consulte Como funciona o Serviço de Metadados de Instância Versão 2.
  4. Na página Especificação da Máquina, selecione um tamanho de máquina. O tamanho da máquina do perfil da máquina (selecionado na página Imagem) é selecionado por padrão.
  5. Na página NICs, selecione ou adicione NICs para a imagem de preparação. Para cada NIC, selecione uma sub-rede VPC associada.
  6. Na página Descrição da Versão, insira uma descrição para a versão inicial da imagem criada.
  7. Na página Resumo, verifique os detalhes da definição da imagem e da versão inicial da imagem criada. Insira um nome e uma descrição para a definição da imagem. Clique em Concluir.

Criar versões de imagem usando o Studio

As versões de imagem permitem o gerenciamento de diferentes iterações ou atualizações de uma imagem específica. Essa funcionalidade permite manter várias versões de uma imagem para diferentes finalidades.

Para criar versões de imagem a partir da versão inicial da imagem, faça o seguinte:

Nota:

A unidade de hospedagem de todas as versões da imagem deve ser a mesma.

  1. Vá para o nó Imagens, selecione uma versão de imagem ou uma definição de imagem e clique em Criar Versão da Imagem.
  2. Na página Definição da imagem, você pode alterar a unidade de hospedagem e selecionar novamente a imagem mestre e o perfil da máquina para essa versão da imagem.
  3. Se você quiser que a configuração da versão da imagem seja diferente da versão inicial da imagem configurada, configure as definições nas páginas Especificação da Máquina e NICs da caixa de diálogo Criar Versão da Imagem.
  4. Adicione uma descrição para a versão da imagem. Clique em Concluir.

Nota:

Se a criação da versão da imagem falhar por qualquer motivo, a guia Solução de problemas na parte inferior fornece uma opção de Repetir.

Criar uma especificação de versão de imagem preparada usando o PowerShell

Os comandos detalhados do PowerShell para criar uma especificação de versão de imagem preparada são os seguintes:

  1. Verifique os nomes de definição de imagem disponíveis usando o Test-ProvImageDefinitionNameAvailable command. Por exemplo,

    Test-ProvImageDefinitionNameAvailable -ImageDefinitionName <string[]>
    <!--NeedCopy-->
    
  2. Crie uma definição de imagem usando o comando New-ProvImageDefinition. Por exemplo,

    New-ProvImageDefinition -ImageDefinitionName image1 -OsType Windows -VdaSessionSupport MultiSession
    <!--NeedCopy-->
    
  3. Crie uma nova configuração para a definição de imagem na conexão de hospedagem especificada usando o comando Add-ProvImageDefinitionConnection.

    Add-ProvImageDefinitionConnection -ImageDefinitionName image1 -HypervisorConnectionName test-conn
    <!--NeedCopy-->
    
  4. Crie uma versão de imagem usando o comando New-ProvImageVersion. Por exemplo,

    New-ProvImageVersion -ImageDefinitionName image1 -Description "version 1"
    <!--NeedCopy-->
    
  5. Adicione uma especificação de versão de imagem mestre à versão da imagem usando o comando Add-ProvImageVersionSpec. Por exemplo,

    Add-ProvImageVersionSpec -ImageDefinitionName  image1  -ImageVersionNumber  1 -HostingUnitName wsc -MasterImagePath "XDHyp:\HostingUnits\wsc\win10-2411-ami (ami-00123456789abcdef).template”"
    <!--NeedCopy-->
    

    Nota:

    Você pode adicionar apenas uma especificação de versão de imagem mestre a uma versão de imagem para uma unidade de hospedagem.

  6. Crie uma especificação de versão de imagem preparada a partir da especificação de versão de imagem mestre usando o comando New-ProvImageVersionSpec. O parâmetro SourceImageVersionSpecUid é derivado do comando Add-ProvImageVersionSpec. Por exemplo,

    New-ProvImageVersionSpec
    -SourceImageVersionSpecUid  00000000-0000-0000-0000-00000000000
    -MachineProfile 'XDHyp:\HostingUnits\wsc\w2022-2411 (lt-00123456789abcdef).launchtemplate\lt-00123456789abcdef (1).launchtemplateversion' -RunAsynchronously
    <!--NeedCopy-->
    

Exemplo do conjunto completo de comandos PowerShell para criar definição de imagem, versão de imagem e especificação de versão de imagem preparada:

New-ProvImageDefinition -ImageDefinitionName image1 -OsType Windows -VdaSessionSupport MultiSession


Add-ProvImageDefinitionConnection -ImageDefinitionName image1 -HypervisorConnectionName wsc -CustomProperties $CustomProperties

$imageVersion = New-ProvImageVersion -ImageDefinitionName image1 -Description "version 1"

$SourceImageVersionSpec = Add-ProvImageVersionSpec -ImageVersionUid $imageVersion.ImageVersionUid `
    -HostingUnitUid $hostingunit.HostingUnitUid `
    -MasterImagePath "XDHyp:\HostingUnits\wsc\win10-2411-ami (ami-00123456789abcdef).template”

New-ProvImageVersionSpec -MachineProfile 'XDHyp:\HostingUnits\wsc\w2022-2411 (lt-00123456789abcdef).launchtemplate\lt-00123456789abcdef (1).launchtemplateversion' -SourceImageVersionSpecUid $SourceImageVersionSpec.ImageVersionSpecUid
Add-ProvImageVersionSpecHostingUnit -ImageVersionSpecUid 00000000-0000-0000-0000-00000000000-HostingUnitName wsc
$PreparedImageVersionSpec = Get-ProvImageVersionSpec -ImageVersionUid $imageVersion.ImageVersionUid | Where SourceImageVersionSpecUid-eq $SourceImageVersionSpec.ImageVersionSpecUid
<!--NeedCopy-->

Nota:

  • Todas as especificações de versão de imagem em uma definição de imagem devem pertencer à mesma unidade de hospedagem.
  • Uma versão de imagem pode ter apenas uma especificação de versão de imagem mestre e uma especificação de versão de imagem preparada.
  • Todas as especificações de versão de imagem devem ter um perfil de máquina.

Compartilhar imagens preparadas entre zonas de disponibilidade e regiões

Agora você pode compartilhar uma única imagem preparada entre diferentes zonas de disponibilidade, vinculadas a diferentes unidades de hospedagem, dentro da mesma região AWS ou em regiões diferentes para suas instâncias gerenciadas do Amazon WorkSpaces Core. Isso permite que você use uma imagem preparada para criar e atualizar catálogos de máquinas MCS em várias zonas de disponibilidade e regiões. Ao compartilhar entre diferentes AZs em regiões diferentes, a versão da imagem preparada será copiada da região original para as regiões de destino.

Você pode manter uma única imagem preparada e usá-la para criar e atualizar catálogos de máquinas em várias zonas de disponibilidade e regiões vinculadas a diferentes unidades de hospedagem. Isso reduz significativamente a sobrecarga de gerenciamento de imagens, garante a consistência entre as implantações e otimiza o processo de provisionamento. Você também pode atualizar facilmente os catálogos de máquinas existentes com imagens preparadas de uma zona de disponibilidade ou região diferente.

Casos de uso

  • Gerenciamento Centralizado de Imagens: Você cria uma imagem preparada em uma zona de disponibilidade (por exemplo, us-east-1a). Você pode então compartilhar esta imagem com outras zonas de disponibilidade como us-east-1b dentro da mesma região AWS us-east-1 ou us-west-1a em uma us-west-1 region diferente. Isso permite que uma única imagem atenda a várias unidades de hospedagem e simplifica a manutenção para você.
  • Criação e Atualização Eficientes de Catálogos: Você pode usar uma imagem preparada criada em AZ 1 (por exemplo, us-east-1a) para criar novos catálogos em AZ 1. Depois de compartilhar esta imagem com AZ 2 (por exemplo, us-east-1b), você pode usar a imagem compartilhada em AZ 2 para criar e atualizar catálogos em AZ 2.
  • Implantações de unidade de hospedagem e conexão de hospedagem cruzadas: Se seu ambiente tiver várias unidades de hospedagem na mesma ou em diferentes regiões AWS, você poderá compartilhar imagens preparadas de forma eficiente entre essas unidades de hospedagem.

Limitações

  • Compartilhamento dentro da mesma conta AWS: Você não pode compartilhar entre diferentes contas AWS na implementação atual.

Considerações importantes

  • Ordem de exclusão: Para excluir uma especificação de versão de imagem preparada original, você deve primeiro excluir todas as suas especificações de versão de imagem compartilhadas. Alternativamente, você deve excluir as especificações original e compartilhada simultaneamente.
  • Dependência da Versão da Imagem: Ao remover uma versão da imagem, você deve primeiro remover quaisquer configurações de compartilhamento que dependam dessa versão específica da imagem. Os catálogos que você criou a partir da imagem original (não compartilhada) podem permanecer intactos.
  • Retrocompatibilidade do Catálogo: Você pode atualizar catálogos de máquinas existentes que você implantou antes da introdução deste recurso. Use imagens preparadas que você criou em uma zona de disponibilidade ou região diferente daquela onde você implantou originalmente o catálogo.
  • Exclusão completa: Ao excluir uma imagem preparada, você não poderá mais usá-la em nenhuma zona de disponibilidade onde a compartilhou ou a criou originalmente. Além disso, uma versão de imagem preparada não pode ser excluída até que todos os catálogos vinculados a essa versão de imagem preparada sejam excluídos primeiro.

Pré-requisitos

Antes de configurar ou usar este recurso, certifique-se de que você atende às seguintes condições:

  • Seu ambiente deve ser um ambiente de instâncias gerenciadas do Amazon WorkSpaces Core.
  • Você deve configurar várias unidades de hospedagem (cada uma pode ser vinculada a diferentes zonas de disponibilidade) e conexões de host (cada uma pode ser vinculada a uma região diferente) na mesma conta AWS.

Configurar usando a interface do usuário do Studio

Você pode compartilhar imagens preparadas entre zonas de disponibilidade vinculadas a diferentes unidades de hospedagem usando a interface do usuário do Studio.

Para compartilhar uma imagem preparada

  1. navegar até o nó Imagens do Studio e selecione a versão da imagem preparada que você deseja compartilhar com outras zonas de disponibilidade.
  2. Selecione Gerenciar Compartilhamento de Imagem na barra de navegação superior para gerenciar o compartilhamento da imagem para a versão da imagem selecionada.
  3. Na página Gerenciar Compartilhamento de Imagem, selecione um ou mais recursos com os quais você deseja compartilhar a versão da imagem. Os recursos podem estar em zonas de disponibilidade diferentes da versão original da imagem.
  4. Clique em Salvar para compartilhar a versão da imagem nos recursos em outras zonas de disponibilidade. A versão da imagem é atualizada para que seja compartilhada entre os diferentes recursos que você selecionou. Uma vez concluído, use a versão da imagem para criar catálogos nas zonas de disponibilidade onde a versão da imagem é compartilhada.

Para remover o compartilhamento de uma imagem preparada

  1. No nó Imagens do Studio, selecione a versão da imagem preparada que você gostaria de remover do compartilhamento.
  2. Selecione Gerenciar Compartilhamento de Imagem na barra de navegação superior para gerenciar o compartilhamento da imagem para a versão da imagem selecionada.
  3. Desmarque as caixas de seleção de um ou mais recursos (zonas de disponibilidade) com os quais você deseja parar de compartilhar a versão da imagem.

    Nota:

    Os recursos não devem mais ter nenhum catálogo associado e criado a partir da versão da imagem compartilhada. Quaisquer catálogos criados a partir da versão da imagem compartilhada a ser removida devem ser excluídos primeiro.

  4. Clique em Salvar para remover o compartilhamento dos recursos nas zonas de disponibilidade limpas. A versão da imagem é atualizada de forma que não seja mais compartilhada nessas zonas de disponibilidade.

Configurar usando o PowerShell

Alternativamente, você pode compartilhar imagens preparadas entre zonas de disponibilidade vinculadas a diferentes unidades de hospedagem usando comandos do PowerShell.

Para compartilhar uma imagem preparada

  1. Certifique-se de ter o ImageVersionSpecUid da imagem preparada que você deseja compartilhar. Você pode recuperá-lo usando Get-ProvImageVersionSpec ou comandos Get- semelhantes no PowerShell.
  2. Determine o HostingUnitName da zona de disponibilidade (pode ser a mesma ou uma região diferente) onde você deseja disponibilizar a imagem preparada. Este é o nome da unidade de hospedagem que você configurou para essa AZ específica.
  3. Execute o comando Add-ProvImageVersionSpecHostingUnit: Use o seguinte comando PowerShell. Substitua <ImageVersionSpecUid> pelo Uid da sua imagem e <targetHostingUnitName> pelo nome da unidade de hospedagem na zona de disponibilidade de destino para a qual você deseja compartilhar a especificação da versão da imagem:

    Add-ProvImageVersionSpecHostingUnit -ImageVersionSpecUid <ImageVersionSpecUid> -HostingUnitName <targetHostingUnitName>
    <!--NeedCopy-->
    
  4. Após a execução bem-sucedida, você pode ver o status da imagem na interface do usuário do Studio indicando que você a compartilhou com a unidade de hospedagem especificada.

Para remover o compartilhamento de uma imagem preparada

  1. Certifique-se de ter o ImageVersionSpecUid da imagem preparada da qual você deseja remover o compartilhamento.
  2. Determine o HostingUnitName da zona de disponibilidade da qual você deseja remover a imagem compartilhada.
  3. Execute o comando Remove-ProvImageVersionSpecHostingUnit: Use o seguinte comando PowerShell. Substitua <ImageVersionSpecUid> pelo Uid da sua imagem e <targetHostingUnitName> pelo nome da unidade de hospedagem na Zona de Disponibilidade de destino da qual você deseja remover o compartilhamento da especificação da versão da imagem:

    Remove-ProvImageVersionSpecHostingUnit -ImageVersionSpecUid <ImageVersionSpecUid> -HostingUnitName <targetHostingUnitName>
    <!--NeedCopy-->
    

Configuração de rede durante a preparação da imagem

Durante a preparação da imagem, uma máquina virtual (VM) de preparação é criada com base na VM original. Esta VM de preparação é desconectada da rede. Para desconectar a rede da VM de preparação, um grupo de segurança de rede é criado para negar todo o tráfego de entrada e saída. Este grupo de segurança de rede persiste e é reutilizado. O nome do grupo de segurança de rede é Citrix.XenDesktop.IsolationGroup-GUID, onde GUID é gerado aleatoriamente.

Um catálogo de máquinas baseado em perfil de máquina

Você pode usar um perfil de máquina para capturar as propriedades de hardware de uma instância EC2 (VM) ou versão de modelo de inicialização e aplicá-las às máquinas provisionadas. As propriedades capturadas podem incluir, por exemplo, tipo de locação, tipo de instância, grupos de segurança, mapeamentos de rede, propriedades de volume EBS, otimização EBS, opções de CPU, capacidade de hibernação e outras configurações AWS suportadas.

Você pode usar uma instância AWS EC2 (VM) ou uma versão de modelo de inicialização AWS como entrada do perfil da máquina.

Nota:

Locação AWS

A AWS oferece as seguintes opções de locação: locação compartilhada (o tipo padrão) e locação dedicada. Locação compartilhada significa que várias instâncias do Amazon WorkSpaces Core de diferentes clientes podem residir no mesmo hardware físico. Locação dedicada significa que suas instâncias do Amazon WorkSpaces Core são executadas apenas em hardware com outras instâncias que você implantou.

Nota:

As instâncias dedicadas são as únicas suportadas (hosts dedicados não são suportados atualmente). Outros clientes não usam a mesma peça de hardware.

O tipo de locação é capturado do perfil da máquina

Quando você usa o MCS para criar um catálogo para provisionar máquinas na AWS, o tipo de locação é capturado do perfil da máquina.

  • Hardware compartilhado: Esta configuração é adequada para a maioria das implantações. Vários clientes compartilham peças de hardware, mesmo que não interajam entre si. Usar hardware compartilhado é a opção menos dispendiosa para executar suas instâncias Amazon EC2.
  • Instância dedicada: Esta configuração é mais adequada para implantações com requisitos específicos de segurança ou conformidade. Com uma instância dedicada, você ainda desfruta dos benefícios de ter um host separado de outros clientes AWS, mas não paga pelo host inteiro. Você não precisa se preocupar com a capacidade do host, mas é cobrado a uma taxa mais alta pelas instâncias. Além disso, as Instâncias Dedicadas fornecem suporte limitado para Bring Your Own License (BYOL).

Faturamento flexível

O Amazon WorkSpaces Core Managed Instances oferece suporte a dois modos de faturamento:

Modo de faturamento Descrição
Mensal Faturamento fixo, mensal e de taxa fixa. Ideal para desktops persistentes e cargas de trabalho previsíveis.
Por hora Faturamento pré-pago. Esta é a configuração padrão da AWS se nenhum modo de faturamento for explicitamente especificado.

Essas opções oferecem flexibilidade para gerenciar os custos de computação com base na persistência e nos padrões de uso da sua carga de trabalho.

Este recurso requer o uso do serviço de faturamento do Amazon WorkSpaces. Por padrão, o MCS usa esse serviço para provisionar e gerenciar instâncias, permitindo que você se beneficie de preços de taxa fixa mais competitivos para cargas de trabalho persistentes.

Pré-requisitos e considerações

  • Configuração da conta AWS: Sua conta AWS deve ser configurada para usar o serviço de faturamento do WorkSpaces. Embora as contas AWS sejam alternadas por padrão, alguns clientes podem solicitar que a AWS permaneça no serviço de faturamento EC2 legado para usar o WorkSpaces Core Managed Instances.

    Nota:

    Se sua conta estiver no serviço de faturamento EC2 legado, a opção de faturamento Mensal não estará disponível.

  • Conexão do host: O faturamento flexível é aplicável apenas a conexões de host do Amazon WorkSpaces Core. Não é compatível com conexões de host AWS EC2 padrão.
  • Instâncias spot: Instâncias spot não são suportadas com o serviço de faturamento do WorkSpaces.
  • Faturamento misto: Uma conta AWS deve usar o faturamento do WorkSpaces ou o faturamento do EC2 para instâncias gerenciadas principais. Uma mistura de ambos em uma única conta não é suportada.
  • Compatibilidade: Apenas tipos de instância específicos, tipos de plataforma (SO) e tipos de locação são compatíveis com certos modos de faturamento. O MCS executa uma verificação prévia para garantir que suas seleções (Oferta de Serviço, Perfil de Máquina e Imagem Preparada) correspondam ao modo de faturamento escolhido.

Consulte Criar um catálogo de máquinas com um modo de faturamento específico.

Uma imagem preparada e um perfil de máquina são necessários para criar catálogos de instâncias gerenciadas do Amazon WorkSpaces Core. Você pode usar uma instância de VM AWS ou uma versão de modelo de inicialização AWS como entrada do perfil de máquina.

Nota:

Atualmente, a criação de catálogos de VMs persistentes e não persistentes (a propriedade CleanOnBoot é True ou False) é suportada.

Antes de criar um catálogo de instâncias gerenciadas do Amazon WorkSpaces Core, você precisa concluir a criação de:

  1. Uma conexão com instâncias gerenciadas do Amazon WorkSpaces Core. Consulte Conexão com instâncias gerenciadas do Amazon WorkSpaces Core
  2. Uma imagem preparada.

Você pode criar um catálogo usando:

Criar um catálogo usando o Studio

Criar um catálogo de máquinas a partir do nó Imagens

Use a opção Criar catálogo no nó Imagens para criar um catálogo usando a versão da imagem.

Alternativamente, você pode selecionar a versão ao criar um catálogo no nó Catálogos de Máquinas, vinculando à opção de imagem preparada no fluxo de trabalho de criação de catálogo. Consulte Criar um catálogo de máquinas a partir do nó Catálogos de Máquinas.

Para criar um catálogo de máquinas MCS a partir do nó Imagens, faça o seguinte:

  1. Selecione uma versão da imagem e clique em Criar catálogo. Clique em Avançar na página Introdução.
  2. Nas páginas Gerenciamento de Máquinas e Imagem, as configurações são pré-selecionadas com base na versão da imagem selecionada. Na página Imagem, insira uma nota para a imagem preparada selecionada.
  3. Conclua as configurações nas páginas seguintes.
  4. Na página Resumo, verifique os detalhes do catálogo de máquinas. Insira um nome e uma descrição para o catálogo de máquinas. Clique em Concluir.
  5. Vá para o nó Catálogos de Máquinas para ver o catálogo de máquinas criado.

Criar um catálogo de máquinas a partir do nó Catálogos de Máquinas

Para criar um catálogo de máquinas MCS a partir do nó Catálogos de Máquinas, faça o seguinte:

  1. Clique em Catálogos de Máquinas no painel de navegação esquerdo.
  2. Clique em Criar Catálogo de Máquinas. A página Configuração do Catálogo de Máquinas é exibida.
  3. Na página Tipo de Máquina, selecione um tipo de máquina para o catálogo, por exemplo, SO de várias sessões.
  4. Na página Gerenciamento de Máquinas, selecione as seguintes configurações:

    1. Selecione Máquinas com gerenciamento de energia (por exemplo, máquinas virtuais ou PCs blade).
    2. Selecione Tecnologia de provisionamento Citrix. Em seguida, selecione Citrix Machine Creation Services™.
    3. No campo Recursos, selecione os recursos (Zona de Disponibilidade ou Zona Local) que você configurou ao criar a conexão do host e clique em Avançar.
  5. Na página Experiência da área de trabalho, selecione a área de trabalho aleatória ou estática que você deseja que os usuários tenham ao fazer login. Se uma área de trabalho estática for selecionada, especifique se você deseja salvar as alterações que o usuário faz no disco local (persistente ou não persistente).
  6. Na página Imagem, clique em Selecionar uma imagem para selecionar uma imagem preparada para o catálogo de máquinas. Selecione a versão preparada que você criou. Clique no nome da versão da imagem. Para ver mais detalhes sobre a versão da imagem selecionada, clique no número da versão, que está sublinhado. Clique em Concluído.

    O perfil da máquina associado à imagem preparada aparece e suas propriedades de hardware (por exemplo, tipo de instância, tipo de locação, mapeamentos de rede, grupos de segurança, propriedades de volume) são usadas para criar máquinas nos catálogos. Para alterar a origem do perfil da máquina para outra VM ou versão de modelo de inicialização, clique no botão de edição.

  7. Na página Máquinas Virtuais:

    1. Insira o número de VMs para o catálogo.
    2. A especificação de máquina padrão é exibida, com base no perfil da máquina. Para alterá-la, selecione o ícone de edição e selecione uma especificação de máquina.
  8. Na página NICs, selecione as NICs (ou ENIs) para as VMs.
  9. Na página Identidades da Máquina, configure o tipo de identidade da máquina para as máquinas no catálogo:

    1. Para configurar máquinas ingressadas no domínio (Active Directory local ou Microsoft Entra híbrido), selecione o domínio e crie novas contas AD para as VMs a serem criadas neste catálogo de máquinas. As VMs provisionadas são ingressadas no domínio selecionado. Para provisionar máquinas não ingressadas no domínio, selecione a opção de não ingressar no domínio.
    2. Especifique o esquema de nomenclatura de conta para as novas contas a serem criadas para as VMs.
  10. Na página Credenciais de domínio, clique em Inserir credenciais para fornecer as credenciais para o domínio selecionado. Insira o nome de usuário e a senha de nível de administrador quando solicitado. Você também pode usar uma conta de serviço se já tiver credenciais de domínio salvas anteriormente, seguindo nossa documentação do produto.
  11. Clique nas páginas restantes até a página Resumo. Insira um nome para o catálogo de máquinas e selecione Concluir para criar o catálogo de máquinas.

Limitações na criação de um catálogo de máquinas em uma zona local da AWS

  • Certas zonas locais suportam apenas determinadas configurações de hardware (por exemplo, a zona local de Perth não suporta volumes GP3, apenas GP2).
  • Como apenas gp2 é universalmente suportado em todas as zonas locais, e nem todas suportam gp3, a criação de disco de ID padroniza o uso do tipo de volume gp2.
  • Você deve selecionar um perfil de máquina com especificações de hardware que sejam suportadas na zona local desejada.
  • Os snapshots de AMIs de imagem preparada e os snapshots de disco de ID são padronizados para serem colocados na região, em vez da zona local (devido às limitações da AWS em relação à visibilidade do suporte a snapshots EBS em zonas locais).
  • Apenas zonas locais que suportam serviços completos de EC2 e EBS são zonas suportadas.

Criar um catálogo usando PowerShell

Criar um catálogo usando uma especificação de versão de imagem preparada e perfil de máquina

  • Crie um catálogo de máquinas não persistentes do MCS a partir da especificação de versão de imagem preparada usando o comando New-ProvScheme. Por exemplo,

     New-ProvScheme -ProvisioningSchemeName <string> -ImageVersionSpecUid <Guid> -HostingUnitUid <Guid> -IdentityPoolUid <Guid> [-CleanOnBoot $true] [-MachineProfile <string>] [-ProvisioningSchemeType “MCS”]
     <!--NeedCopy-->
    
  • Crie um catálogo de máquinas persistentes do MCS a partir da especificação de versão de imagem preparada usando o comando New-ProvScheme. Por exemplo,

     New-ProvScheme -ProvisioningSchemeName <string> -ImageVersionSpecUid <Guid> -HostingUnitUid <Guid> -IdentityPoolUid <Guid> [-CleanOnBoot $false] [-MachineProfile <string>] [-ProvisioningSchemeType “MCS”]
     <!--NeedCopy-->
    

Exemplo do conjunto completo de comandos Powershell para criar um catálogo:

$Catalog = New-BrokerCatalog  -AllocationType "Random"  -IsRemotePC $False  -MinimumFunctionalLevel "L7_20" -Name "wsccatalog" -PersistUserChanges "Discard" -ProvisioningType "MCS" -Scope @() -SessionSupport "MultiSession"

$IdentityPool = New-AcctIdentityPool  -AllowUnicode  -Domain "domainname" -IdentityPoolName "wsccatalog" -IdentityType "ActiveDirectory"  -NamingScheme "aws##" -NamingSchemeType "Numeric" -Scope @()

$PreparedImageVersionSpec = Get-ProvImageVersionSpec -ImageDefinitionName image1 -ImageVersionNumber 1 -Filter "PreparationType -eq 'Mcs'"

$Task = New-ProvScheme -ProvisioningSchemeName wsccatalog -ImageVersionSpecUid $PreparedImageVersionSpec.ImageVersionSpecUid -HostingUnitName wsc -IdentityPoolName wsccatalog -CleanOnBoot -Scope @() -SecurityGroup @() -MachineProfile 'XdHyp:\HostingUnits\cvad-test-scalestress\us-east-1a.availabilityzone\machine-profile-instance i (i-0xxxxxxxx).vm' -RunAsynchronously

Get-ProvTask -TaskId $Task.TaskId
$ProvScheme = Get-ProvScheme -ProvisioningSchemeName wsccatalog

Set-BrokerCatalog -Name $Catalog.Name -ProvisioningSchemeId $ProvScheme.ProvisioningSchemeUid
<!--NeedCopy-->

Atualizar o perfil da máquina

Para atualizar o perfil da máquina em um catálogo que foi inicialmente provisionado com um perfil de máquina, faça o seguinte. Você também pode alterar o tipo de locação e a capacidade de hibernação da origem do perfil da máquina ao editar um catálogo de máquinas MCS.

  1. Execute o comando Set-ProvScheme. Por exemplo,

    Set-ProvScheme `
    -ProvisioningSchemeUid "<ID" `
    -MachineProfile "XDHyp:\HostingUnits\abc\us-east-1a.availabilityzone\citrix-cvad-machineprofile-instance (i-0xxxxxxxx).vm"
    <!--NeedCopy-->
    

Criar um catálogo de máquinas com um modo de faturamento específico

Atualmente, você pode especificar o modo de faturamento ao criar um catálogo de máquinas usando apenas o PowerShell.

Para especificar o modo de faturamento via PowerShell, use o parâmetro CustomProperties no comando New-ProvScheme.

$custprop = "BillingMode,Monthly"

New-ProvScheme -ProvisioningSchemeName "MyCatalog" `
-ImageVersionSpecUid $ImageVersionSpecUid `
-HostingUnitName "wsc-unit" `
-IdentityPoolName "MyIdentityPool" `
-MachineProfile "XdHyp:\HostingUnits\wsc-unit\machine-profile lt-123.launchtemplate\lt-123 (1).launchtemplateversion" `
-CustomProperties $custprop `
-CleanOnBoot
<!--NeedCopy-->

Nota:

Se a propriedade BillingMode for omitida, o catálogo assume o padrão Hourly.

Alterar o modo de faturamento de um catálogo existente

Você pode converter um catálogo existente de Monthly para Hourly, ou vice-versa. Essa alteração pode ser aplicada a VMs novas e existentes no catálogo.

Considerações importantes para atualizações

  • Janela de serviço: As VMs existentes devem passar por uma janela de serviço ou ciclo de energia para aplicar a alteração de faturamento.
  • Validação: O MCS valida se os tipos de instância e plataformas existentes são compatíveis com o novo modo de faturamento antes de aplicar a alteração.

Atualizar usando PowerShell

  • Para atualizar o modo de faturamento apenas de novas VMs adicionadas a um catálogo, atualize a propriedade personalizada do modo de faturamento do esquema de provisionamento:

     $custprop = "BillingMode,Hourly"
    
     Set-ProvScheme -ProvisioningSchemeName "MyCatalog" -CustomProperties $custprop
     <!--NeedCopy-->
    
  • Para atualizar o modo de faturamento de VMs novas e existentes em um catálogo, crie uma nova versão do esquema de provisionamento com a propriedade personalizada atualizada e aplique a nova versão a todas as VMs:

     $custprop = "BillingMode,Hourly"
    
     New-ProvSchemeVersion -ProvisioningSchemeName "MyCatalog" -CustomProperties $custprop
    
     New-ProvSchemeHardwareUpdate -ProvisioningSchemeVersion 2 `
     -StartsNow -AllVMs `
     -MaxDurationInMinutes 100 `
     -ProvisioningSchemeName "MyCatalog"
     <!--NeedCopy-->
    

Monitorar informações de faturamento

Você pode verificar o modo de faturamento para catálogos e máquinas virtuais individuais.

Execute os seguintes comandos do PowerShell para verificar a elegibilidade de faturamento da sua conta:

  • Retorna BillingMode como parte de CustomProperties

     Get-ProvScheme –ProvisioningSchemeName “"MyCatalog" "  | Select  ProvisioningSchemeName,  CustomProperties
     <!--NeedCopy-->
    
  • Retorna BillingMode como parte de VMInfo

     Get-ProvVMDetails –ProvisioningSchemeName “"MyCatalog" "  | Select-Object  -ExpandProperty VMInfo
     <!--NeedCopy-->
    

Solução de problemas e validação

O MCS inclui verificações de pré-voo para evitar configurações incompatíveis. Você pode encontrar os seguintes erros durante a criação ou edição do catálogo:

  • NoInstanceConfigFoundForBillingMode: Ocorre se a Oferta de Serviço selecionada (tipo de instância), Tenancy e Tipo de Plataforma não forem suportados para o modo de faturamento escolhido.

  • Spot Instance Not Supported: Se você tentar usar instâncias Spot com uma conexão de host do WorkSpaces, a validação falhará.
  • Restrição de faturamento do EC2: Se sua conta AWS estiver no modelo de faturamento EC2 legado, tentar definir um modo de faturamento Mensal resultará em um erro de validação.

Criar um catálogo com a versão do modelo de inicialização usando o PowerShell

Você pode criar um catálogo de máquinas MCS com uma versão de modelo de inicialização como entrada de perfil de máquina. Você também pode atualizar a entrada de um catálogo de perfil de máquina de uma VM para uma versão de modelo de inicialização e de uma versão de modelo de inicialização para uma VM.

No console do AWS EC2, você pode fornecer as informações de configuração da instância de um modelo de inicialização junto com o número da versão. Ao especificar a versão do modelo de inicialização como entrada de perfil de máquina durante a criação ou atualização de um catálogo de máquinas, as propriedades dessa versão do modelo de inicialização são copiadas para as VMs VDA provisionadas.

As seguintes propriedades podem ser fornecidas usando a entrada do perfil da máquina ou explicitamente como parâmetros nos comandos New-ProvScheme ou Set-ProvScheme. Se forem fornecidas nos comandos New-ProvScheme ou Set-ProvScheme, elas terão precedência sobre os valores do perfil da máquina dessas propriedades.

  • Oferta de Serviço
  • Redes

Nota:

Se a oferta de serviço não for fornecida no modelo de inicialização do perfil da máquina ou como um parâmetro no comando New-ProvScheme, você receberá um erro apropriado.

Para criar um catálogo usando a versão do modelo de inicialização como entrada de perfil de máquina:

  1. Abra uma janela do PowerShell.
  2. Execute asnp citrix* para carregar os módulos PowerShell específicos da Citrix.
  3. Obtenha a lista de versões de modelo de inicialização de um modelo de inicialização. Por exemplo:

    XDHyp:\HostingUnits\test\test-mp-sard (lt-01xxxxx).launchtemplate> ls | Select FullPath
    <!--NeedCopy-->
    
  4. Crie um pool de identidades, se ainda não tiver sido criado. Por exemplo:

    New-AcctIdentityPool `
    -IdentityPoolName "abc11" `
    -NamingScheme "abc1-##" `
    -NamingSchemeType Numeric `
    -Domain "citrix-xxxxxx.local" `
    -ZoneUid "xxxxxxxx" `
    <!--NeedCopy-->
    
  5. Crie um esquema de provisionamento com uma versão de modelo de inicialização como entrada de perfil de máquina. Por exemplo:

    New-ProvScheme `
    -ProvisioningSchemeName "MPLT1" `
    -HostingUnitUid "c7f71f6a-3f45-4xxx-xxxx-xxxxxxxxxx" `
    -IdentityPoolUid "bf3a6ba2-1f80-4xxx-xxxx-xxxxxxxxx" `
    -ImageVersionSpecUid ‘24dfb047-e867-527g-896c-25664xxxxx1t’ `
    -CleanOnBoot `
    -MachineProfile "XDHyp:\HostingUnits\xxxx-ue1a\machineprofiletest (lt-01xxxxx).launchtemplate\lt-01xxxxx (1).launchtemplateversion"
    <!--NeedCopy-->
    
  6. Registre um esquema de provisionamento como um catálogo de broker. Por exemplo:

    New-BrokerCatalog -Name "MPLT1" `
    -AllocationType Random `
    -Description "Machine profile catalog" `
    -ProvisioningSchemeId fe7df345-244e-4xxxx-xxxxxxxxx `
    -ProvisioningType Mcs `
    -SessionSupport MultiSession `
    -PersistUserChanges Discard
    <!--NeedCopy-->
    
  7. Conclua a criação do catálogo.

Atualizar a origem do perfil da máquina

Você também pode atualizar a entrada de um catálogo de perfil de máquina de uma VM para uma versão de modelo de inicialização e de uma versão de modelo de inicialização para uma VM. Por exemplo:

  • Para atualizar a entrada de um catálogo de perfil de máquina de uma VM para uma versão de modelo de inicialização:

     Set-ProvScheme -ProvisioningSchemeName "CloudServiceOfferingTest" `
     -MachineProfile "XDHyp:\HostingUnits\xxxx-ue1a\machineprofiletest (lt-0bxxxxxxxxxxxx).launchtemplate\lt-0bxxxxxxxxxxxx (1).launchtemplateversion"
     <!--NeedCopy-->
    
  • Para atualizar a entrada de um catálogo de perfil de máquina de uma versão de modelo de inicialização para uma VM:

     Set-ProvScheme -ProvisioningSchemeName "CloudServiceOfferingTest" `
     -MachineProfile "XDHyp:\HostingUnits\sard-ue1a\us-east-1a.availabilityzone\apollo-non-persistent-vda-win2022-2 (i-08xxxxxxxxx).vm"
     <!--NeedCopy-->
    

Catálogo habilitado para MCSIO

A Otimização de Armazenamento MCS (MCSIO) melhora o desempenho de E/S da máquina virtual armazenando em cache as operações de gravação em disco por meio de um mecanismo de duas camadas:

  • na memória, ou
  • em um disco dedicado de alta velocidade (transborda para o disco quando a memória está cheia).

Para instâncias gerenciadas do Amazon WorkSpaces Core, habilitar o MCSIO anexa um disco de Cache de Gravação (WBC) a cada VM provisionada, além dos discos padrão de SO e Identidade.

Habilite e configure o MCSIO usando:

  • Studio
  • PowerShell

Use o Studio para habilitar o MCSIO

Pré-requisitos

Antes de configurar o MCSIO no Studio, certifique-se do seguinte:

  • O driver MCSIO está instalado na imagem mestre (AMI). Ao instalar ou atualizar o VDA, selecione a opção para instalar o driver MCSIO. Por padrão, o driver não é instalado.
  • Uma versão de imagem preparada é criada a partir de uma imagem mestre que inclui o driver MCSIO.
  • O catálogo de máquinas usa uma experiência de desktop não persistente (CleanOnBoot). O MCSIO se aplica a catálogos VDI não persistentes.

Crie um catálogo de máquinas habilitado para MCSIO usando o Studio

Conclua as etapas anteriores de criação do catálogo (Tipo de Máquina, Gerenciamento de Máquina, Experiência de Desktop, Imagem, Máquinas Virtuais, NICs, Identidades de Máquina, Credenciais de Domínio) conforme descrito em Criar um catálogo. Ao chegar à página Configurações de Disco, faça o seguinte:

  1. Na página Configurações de Disco, selecione a caixa de seleção Habilitar e configurar cache de gravação para desempenho ideal de E/S.
  2. Configure as configurações do disco de cache de gravação:

    • Tamanho do cache de disco (GB): Insira o tamanho em gigabytes do disco usado para cache. O valor deve ser de pelo menos 1 GB e não deve exceder o tamanho do disco do SO.
    • Letra da unidade de disco: Selecione Atribuição automática para permitir que o sistema atribua uma letra de unidade, ou especifique uma letra de unidade manualmente.
    • Memória alocada para cache (MB): Insira a quantidade de memória em megabytes a ser alocada para cache. O valor deve ser maior que zero e menor que a memória total da máquina.

    Nota:

    O cache de write-back exige que o driver MCSIO esteja instalado na imagem mestre.

  3. Em Selecionar o tipo de armazenamento para o disco de cache de write-back, selecione um tipo de volume EBS SSD:

    Tipo de armazenamento:

    • SSD de Uso Geral (gp2)
    • SSD de Uso Geral (gp3)
    • SSD de IOPS Provisionadas (io1)
    • SSD de IOPS Provisionadas (io2)

    Nota:

    O cache de write-back suporta apenas tipos de volume EBS SSD. Tipos de volume HDD e armazenamento de instância local (armazenamento efêmero) não são suportados.

  4. Em Selecionar o tipo de persistência para o disco de cache de write-back, selecione uma das seguintes opções:

    • Usar disco de cache de write-back não persistente: O disco de cache é criado quando a máquina é ligada e excluído quando é desligada. Este é o padrão.
    • Usar disco de cache de write-back persistente: O disco de cache é retido entre os ciclos de energia.
  5. Em Disco do sistema, opcionalmente selecione Reter disco do sistema durante ciclos de energia para manter o disco do SO quando a máquina for desligada. Quando ativado, as máquinas pulam a recriação do disco raiz a partir do modelo em cada inicialização, o que reduz o tempo de inicialização.

    Nota:

    Para um desempenho de inicialização ideal, habilite Usar disco de cache de write-back persistente e Reter disco do sistema durante ciclos de energia. Com ambas as opções ativadas, as máquinas reutilizam o disco de cache e o disco do SO existentes na inicialização, em vez de inicializar novos.

  6. Clique em Avançar para prosseguir pelas páginas restantes do assistente.
  7. Na página Resumo, verifique as configurações relacionadas ao MCSIO antes de finalizar. O resumo exibe os seguintes campos de cache de write-back:

    • Habilitar cache de disco temporário
    • Tamanho do cache de memória (MB)
    • Tamanho do cache de disco (GB)
    • Persistente com disco de cache de write-back
    • Tipo de disco de cache de write-back
    • Letra da unidade do disco de cache de write-back
    • Reter disco do sistema
  8. Insira um nome e uma descrição opcional para o catálogo de máquinas e clique em Concluir.

Atualizar configurações do MCSIO em um catálogo existente usando o Studio

Você pode atualizar as configurações de cache de write-back em um catálogo existente em Editar Catálogo de Máquinas.

Nota:

As alterações feitas na página Configurações de Disco aplicam-se apenas a novas máquinas que você adicionar ao catálogo posteriormente. As máquinas existentes permanecem inalteradas.

  1. Em Catálogos de Máquinas, selecione o catálogo a ser atualizado e clique em Editar Catálogo de Máquinas.
  2. navegar para a página Configurações de Disco. Atualize qualquer uma das seguintes configurações:

    • Tamanho do cache de disco (GB): Altere o tamanho do disco de cache de write-back.
    • Memória alocada para cache (MB): Altere a memória alocada para o cache.
    • Tipo de armazenamento: Altere o tipo de volume EBS para o disco de cache de write-back.
    • Tipo de persistência: Alterne entre disco de cache de write-back persistente e não persistente.
    • Reter disco do sistema durante ciclos de energia: Ative ou desative a retenção do disco do SO.
  3. Clique em Aplicar para salvar sem fechar, ou em Salvar para salvar e fechar.

Layout do disco EBS para máquinas com MCSIO ativado

Quando o MCSIO está ativado, cada VM do Amazon WorkSpaces Core provisionada tem três volumes EBS anexados. Você pode verificar o layout do disco no Console de Gerenciamento da AWS na seção Elastic Block Store dos detalhes da instância EC2.

Disco Índice do Dispositivo Descrição
Disco do SO /dev/sda1 Volume raiz clonado da imagem preparada. Se a opção Retain system disk during power cycles estiver ativada, este disco persistirá quando a máquina for desligada.
Disco de identidade o xvdf Armazena informações de identidade da máquina para a VM provisionada. Sempre persiste.
Disco de cache de write-back o xvdg Disco de cache de alta velocidade para operações de gravação MCSIO. Persiste entre ciclos de energia somente se a opção Use persistent write-back cache disk for MCSIO write operations estiver selecionada.

Referência de comportamento do cache de write-back e do disco do SO

A tabela a seguir resume como o cache de write-back e o disco do SO se comportam com base nas configurações de persistência selecionadas.

Persistência do WBC Retenção do Disco do SO Ao desligar Desempenho de inicialização Custos de armazenamento quando a VM está desligada
Não persistente (padrão) Desabilitado (padrão) Tanto o disco WBC quanto o disco do SO são excluídos. Novos discos são criados na próxima inicialização. Padrão Sem custos de disco do SO ou disco WBC.
Não persistente (padrão) Habilitado O disco WBC é excluído. O disco do SO é retido. Mais rápido — ignora a inicialização do disco do SO Custos de disco do SO, sem custos de disco WBC.
Persistente Desabilitado (padrão) O disco WBC é retido. O disco do SO é excluído e recriado a partir do modelo na próxima inicialização. Mais rápido — ignora a inicialização do WBC Custos de disco WBC, sem custos de disco do SO.
Persistente Ativado Ambos o disco WBC e o disco do SO são retidos. Mais rápido — nenhuma inicialização de disco necessária Custos de disco do SO e disco WBC.

Nota:

Ativar a retenção do disco do SO em um catálogo não persistente significa que o disco do SO não é redefinido na reinicialização. Isso troca tempos de inicialização mais rápidos por custos de armazenamento do disco do SO. Todas as gravações, no entanto, ainda vão apenas para o cache de memória Write-back ou para o disco de cache Write-back. As alterações do usuário não são acumuladas no disco do SO, mesmo ao ativar a retenção do disco do SO. Avalie com base nos requisitos do seu ambiente.

Usar PowerShell para ativar o MCSIO

Criar um catálogo com MCSIO ativado usando PowerShell

Os quatro parâmetros adicionados ao comando PowerShell New-ProvScheme são:

  • UseWriteBackCache: Ativa o cache (cache de write-back) para o esquema de provisionamento fornecido
  • WriteBackCacheDiskSize: Especifica o tamanho em GB do disco temporário usado para cache
  • WriteBackCacheMemorySize: Especifica a quantidade de memória em MB a ser usada para cache. Este é um parâmetro opcional.

Nota:

  • O valor de WriteBackCacheDiskSize deve ser maior que zero porque é necessário pelo menos 1 GB de armazenamento em disco de cache. O tamanho do disco de cache não deve ser maior que o tamanho do disco do SO.
  • O valor de WriteBackCacheMemorySize deve ser diferente de zero e menor que o tamanho da memória do catálogo de máquinas.

As propriedades personalizadas que afetam o MCSIO são:

  • WBCDiskStorageType: Define o tipo de volume, que é usado para o disco temporário em instâncias gerenciadas do Amazon WorkSpaces Core. Este parâmetro aceita um argumento de string no formato volume-type[:iops][:throughput]. Os seguintes são os tipos de volume:

    • gp2: Não use os parâmetros iops e throughput para este tipo de volume
    • gp3: Use os parâmetros iops e throughput para este tipo de volume
    • io1: Use apenas o parâmetro iops para este tipo de volume
    • io2: Use apenas o parâmetro iops para este tipo de volume

    O tipo de volume padrão é gp2.

  • PersistWBC: Controla se o disco de cache deve ser mantido ou descartado sempre que as instâncias gerenciadas do Amazon WorkSpaces Core forem desligadas. Se definido como true, o disco de cache é mantido. Se definido como false (o padrão), o disco de cache é criado e mantido apenas enquanto a instância AMI estiver ligada.
  • PersistOSDisk: Controla se o disco do SO deve ser mantido ou descartado sempre que as instâncias gerenciadas do Amazon WorkSpaces Core forem desligadas. Se definido como true, o disco do SO é mantido. Se definido como false (o padrão), o disco do SO é criado e mantido apenas enquanto a instância AMI estiver ligada.

Execute as seguintes etapas na janela do PowerShell para criar um catálogo não persistente habilitado para MCSIO:

  1. Abra a janela do PowerShell.
  2. Execute asnp citrix* para carregar os módulos PowerShell específicos da Citrix.
  3. Crie um catálogo de broker e um pool de identidade.
  4. Crie o esquema de provisionamento. Por exemplo:

    $HostingUnitUid = '0xxxx1d9-bbfc-xxxf-bxxb-exxxxxe008b2'
    $MasterImageVM = 'XDHyp:\HostingUnits\ctx-test\aws-apollo-non-persistent-multi-mcsio-vda-win2022 (ami-0bf1810488acbxxxb).template'
    $NetworkMap = @{ 'NetworkPath' = 'XDHyp:\HostingUnits\ctx-test\us-east-1a.availabilityzone\10.0.128.0`/17 (vpc-0fa6e41d72507fxxx).network' }
    $SecurityGroup = $( 'XDHyp:\HostingUnits\ctx-test\us-east-1a.availabilityzone\private.securitygroup' )
    $ServiceOffering = 'XDHyp:\HostingUnits\ctx-test\T3 Medium Instance.serviceoffering'
    $CustomProperties = 'WBCDiskStorageType,gp3:6000:250;PersistWBC,false'
    
    $provScheme = New-ProvScheme -ProvisioningSchemeName $CatalogName -HostingUnitUid $HostingUnitUid `
    -IdentityPoolUid $acctPool.IdentityPoolUid -CleanOnBoot `
    - MasterImageVM $MasterImageVM `
    -NetworkMap $NetworkMap `
    -ServiceOffering $ServiceOffering `
    -SecurityGroup $SecurityGroup `
    -CustomProperties $CustomProperties `
    -UseWriteBackCache -WriteBackCacheDiskSize 16 -WriteBackCacheMemorySize 256
    <!--NeedCopy-->
    
  5. Adicione VMs ao catálogo.

Melhore o desempenho de inicialização com MCSIO

Você pode melhorar o desempenho de inicialização de VMs se habilitar o MCSIO e definir as propriedades personalizadas PersistWBC e PersistOSDisk como true. Com essa configuração, as VMs podem inicializar mais rapidamente porque não precisam inicializar um novo disco de cache ou recriar um disco raiz a partir de seu modelo.

Criptografar discos de SO e ID

Você pode criar um catálogo de VMs com chaves AWS KMS (chave gerenciada pelo cliente e chave gerenciada pela AWS) que podem ser usadas para criptografar o disco do SO e o disco de identidade (ID).

  • As chaves gerenciadas pela AWS são rotacionadas automaticamente todos os anos.
  • As chaves gerenciadas pelo cliente são opcionais para rotação automática e podem ser gerenciadas manualmente.

Você pode consultar os seguintes documentos da AWS para obter mais informações sobre chaves KMS:

Para criptografia de discos de SO e ID, configure um dos seguintes:

  • Use uma imagem preparada que esteja criptografada (por exemplo, uma AMI criada a partir de uma instância ou snapshot que contém um volume raiz EBS criptografado com chave KMS)
  • Use uma fonte de perfil de máquina (VM ou modelo de inicialização) que contenha um volume raiz EBS criptografado.

Limitações

Considere as seguintes limitações:

  • O MCS atualmente suporta apenas um disco na AMI de imagem preparada.
  • Não é possível criptografar diretamente volumes ou snapshots EBS existentes não criptografados, nem modificar a chave KMS de um volume criptografado existente. Para fazer isso, você deve:

    1. Criar um novo snapshot desse volume.
    2. Criar um novo volume a partir desse snapshot
    3. Criptografar o novo volume.

Consulte os seguintes documentos da AWS:

Criar um catálogo com criptografia de disco

Você pode criar um catálogo de máquinas MCS com criptografia de disco usando:

  • Imagem preparada (criada usando o gerenciamento de imagens a partir de uma imagem mestre que possui disco criptografado)
  • Perfil de máquina

As considerações ao usar a entrada do perfil da máquina são:

  • A chave KMS da entrada do perfil da máquina tem precedência sobre a chave KMS da imagem preparada.
  • Se nenhuma entrada de perfil de máquina for fornecida, a chave KMS da AMI da imagem preparada será usada para criptografar os discos das VMs do catálogo.
  • Se o perfil da máquina tiver Mapeamentos de Dispositivos de Bloco presentes, os dispositivos de bloco presentes no modelo de imagem preparada (AMI) e o perfil da máquina devem corresponder. Por exemplo, se a AMI tiver um dispositivo definido em /dev/sda1, o Perfil da Máquina também deverá ter um dispositivo definido em /dev/sda1.
  • Se não houver chave na origem do perfil da máquina e a imagem preparada não estiver criptografada, os discos das VMs do catálogo não serão criptografados.
  • Quando a imagem preparada é criptografada, uma VM de origem de perfil de máquina ou um modelo de inicialização deve ter um volume raiz criptografado para ser considerado uma entrada válida.

Modificar um catálogo existente

Você pode modificar um catálogo existente usando o comando PowerShell Set-ProvScheme para ter:

  • Uma entrada de perfil de máquina com um volume contendo uma nova chave KMS.
  • Uma imagem preparada criada a partir da imagem mestre com AMI criptografada usando gerenciamento de imagem.

Considerações importantes:

  • Os volumes de novas VMs adicionadas ao catálogo são criptografados com a nova chave KMS.
  • Para atualizar as configurações de criptografia quando houver um perfil de máquina existente, execute Set-ProvScheme com um novo perfil de máquina.
  • Você não pode modificar um catálogo existente de volumes criptografados para volumes não criptografados. Você não pode fazer uma atualização de imagem de uma AMI de imagem preparada criptografada para uma AMI de imagem preparada não criptografada.

Habilitar NitroTPM e inicialização segura UEFI para instâncias de VM

Ao criar um catálogo, agora você pode selecionar uma imagem preparada (AMI) com NitroTPM e/ou inicialização segura UEFI habilitados. Consequentemente, as VMs provisionadas no catálogo também são habilitadas com NitroTPM e/ou inicialização segura UEFI. Essa implementação garante que as VMs sejam seguras e confiáveis. Para obter mais informações sobre NitroTPM e Inicialização Segura UEFI, consulte a documentação da Amazon.

Limitações

  • Atualmente, você pode usar NitroTPM e Secure Boot em todas as regiões da AWS (incluindo as regiões AWS GovCloud (EUA)), exceto na China.
  • Você não pode habilitar o NitroTPM e o Secure Boot UEFI em catálogos existentes. Se você deseja um catálogo com NitroTPM e Secure Boot UEFI habilitados, crie um novo catálogo.

Etapas principais

  1. Configure seu ambiente AWS.
  2. Crie uma conexão com a AWS.
  3. Crie uma imagem mestre (AMI) habilitada com NitroTPM e/ou Secure Boot UEFI.
  4. Crie uma imagem preparada a partir da imagem mestre. Consulte Criar uma imagem preparada para instâncias gerenciadas do Amazon WorkSpaces Core.
  5. Crie um catálogo de máquinas selecionando a imagem preparada com NitroTPM e Secure Boot UEFI habilitados no menu de criação de catálogo do Citrix Studio ou ao criar um Esquema de Provisionamento usando comandos PowerShell.

As VMs adicionadas ao catálogo criado têm NitoTPM e Secure Boot UEFI habilitados.

Crie uma AMI que suporte NitroTPM e Secure Boot UEFI

  1. Você pode criar uma AMI a partir de uma VM que tenha NitroTPM e/ou Secure Boot UEFI habilitados.

    1. Crie a instância usando as imagens do AWS Marketplace. Por exemplo, pesquise por TPM-Windows_Server-2022-English-Full-Base on the aws-marketplace.
    2. Baixe o VDA de sessão única ou múltipla.
    3. Crie uma AMI a partir dessa VM.
  2. Use o comando register-image:

    --boot-mode (string)
    --tpm-support (string)
    <!--NeedCopy-->
    

    Para obter mais informações, consulte register-image.

Consulte os seguintes documentos da AWS:

Você pode abrir uma janela do PowerShell a partir do host do Delivery Controller™ para verificar se um específico:

  • oferta de serviço suporta NitroTPM ou inicialização segura UEFI

     (Get-Item -Path “XDHyp:\HostingUnits\aws\T3 Medium Instance.serviceoffering”).AdditionalData.BootMode
     (Get-Item -Path “XDHyp:\HostingUnits\aws\T3 Medium Instance.serviceoffering”).AdditionalData.NitroTpmSupportVersions
     <!--NeedCopy-->
    
  • modelo suporta NitroTPM ou inicialização segura UEFI

     (Get-HypInventoryItem -LiteralPath “XDHyp:\HostingUnits\aws” -ResourceType “template -Id “ID”).AdditionalData.BootMode
    
     (Get-HypInventoryItem -LiteralPath “XDHyp:\HostingUnits\aws” -ResourceType “template -Id “ID”).AdditionalData.TpmSupport
     <!--NeedCopy-->
    

Atualizar a oferta de serviço do catálogo existente

Você pode alterar a oferta de serviço de um catálogo existente usando Set-ProvScheme. A alteração se aplica às VMs recém-adicionadas. No entanto, você recebe erros nos seguintes cenários:

Modo de inicialização das AMIs A AMI suporta Nitro TPM? A oferta de serviço suporta NitroTPM e inicialização segura UEFI?
UEFI Não Não
BIOS Herdado Sim Não
UEFI Sim Não
UEFI Preferencial Sim Não

Copiar tags em VMs

Você pode copiar tags em NICs e discos (disco de identidade, disco de cache de gravação e disco do SO) que são especificados no perfil da máquina para VMs recém-criadas em um catálogo de máquinas MCS. Você pode especificar essas tags em qualquer uma das fontes de perfil da máquina (instância de VM AWS ou versão de modelo de inicialização AWS). Este recurso é aplicável a catálogos de máquinas e VMs persistentes e não persistentes.

Nota:

  • No console do AWS EC2, você não pode ver os valores de Tag Network Interfaces em Launch Template Version Resource Tags. No entanto, você pode executar o comando PowerShell aws ec2 describe-launch-template-versions --launch-template-id lt-0bb652503d45dcbcd --versions 12 para ver as especificações da tag.
  • Se uma fonte de perfil de máquina (VM ou versão de modelo de inicialização) tiver duas interfaces de rede (eni-1 e eni-2), e eni-1 tiver a tag t1 e eni-2 tiver a tag t2, então a VM receberá as tags de ambas as interfaces de rede.

Filtrar instâncias de VM usando PowerShell

Uma instância de VM da AWS que você usa como VM de perfil de máquina deve ser compatível para que o catálogo de máquinas seja criado e funcione corretamente. Para listar as instâncias de VM da AWS que podem ser usadas como VMs de entrada de perfil de máquina, você pode usar o comando Get-HypInventoryItem. O comando pode paginar e filtrar o inventário de VMs disponíveis em uma unidade de hospedagem.

Paginação:

Get-HypInventoryItem oferece suporte a dois modos de paginação:

  • O modo de paginação usa os parâmetros -MaxRecords e -Skip para retornar conjuntos de itens:
    • -MaxRecords: O padrão é 1. Isso controla quantos itens devem ser retornados.
    • -Skip: O padrão é 0. Isso controla quantos itens devem ser ignorados desde o início absoluto (ou fim absoluto) da lista no hipervisor.
  • O modo de rolagem usa os parâmetros -MaxRecords, -ForwardDirection e -ContinuationToken para permitir a rolagem dos registros:
    • -ForwardDirection: O padrão é True. Isso é usado junto com -MaxRecords para retornar o próximo conjunto de registros correspondentes ou o conjunto anterior de registros correspondentes.
    • -ContinuationToken: Retorna os itens imediatamente depois (ou antes, se ForwardDirection for false), mas não incluindo o item fornecido em ContinuationToken.

Exemplos de paginação:

  • Para retornar um único registro do modelo de máquina com o nome mais baixo. O campo AdditionalData tem o TotalItemsCount e o TotalFilteredItemsCount:

     Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template
     <!--NeedCopy-->
    
  • Para retornar 10 registros do modelo de máquina com o nome mais baixo:

     Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -MaxRecords 10 | select Name
     <!--NeedCopy-->
    
  • Para retornar um array de registros terminando com o nome mais alto:

     Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -ForwardDirection $False -MaxRecords 10 | select Name
     <!--NeedCopy-->
    
  • Para retornar um array de registros começando no modelo de máquina associado ao ContinuationToken fornecido:

     Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -ContinuationToken "ami-07xxxxxxxxxx" -MaxRecords 10
     <!--NeedCopy-->
    

Filtragem:

Os seguintes parâmetros opcionais adicionais são suportados para filtragem. Você pode combinar esses parâmetros com as opções de paginação.

  • -ContainsName "my_name": Se a string fornecida corresponder a parte de um nome de AMI, a AMI será incluída no resultado Get. Por exemplo:

     Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -MaxRecords 100 -ContainName ‘apollo’ | select Name
     <!--NeedCopy-->
    
  • -Tags '{ "Key0": "Value0", "Key1": "Value1", "Key2": "Value2" }': Se uma AMI tiver pelo menos uma dessas tags, ela será incluída no resultado Get. Por exemplo:

     Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -MaxRecords 100 -Tags '{"opex owner": "Not tagged"}' | select Name
     <!--NeedCopy-->
    

    Nota:

    Dois valores de tag são suportados. O valor de tag Não Marcado corresponde a itens que não possuem a tag fornecida em sua lista de tags. O valor de tag Todos os valores corresponde a itens que possuem a tag, independentemente do valor da tag. Caso contrário, a correspondência ocorre apenas se o item tiver a tag e o valor for igual ao que é fornecido no filtro.

  • -Id "ami-0a2d913927e0352f3": Se a AMI corresponder ao ID fornecido, ela será incluída no resultado Get. Por exemplo:

     Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -Id ami-xxxxxxxxxxxxx
     <!--NeedCopy-->
    

Filtragem no parâmetro AdditionalData:

O parâmetro de filtro AdditionalData lista modelos ou VMs com base em sua capacidade, oferta de serviço ou qualquer propriedade que esteja em AdditionalData. Por exemplo:

(Get-HypInventoryItem -ResourceType "launchtemplateversion" -LiteralPath "XDHyp:\HostingUnits\aws" -MaxRecords 200).AdditionalData
<!--NeedCopy-->

Você também pode adicionar um parâmetro -Warn para indicar as VMs incompatíveis. As VMs são incluídas com um campo AdditionalData chamado Warning. Por exemplo:

(Get-HypInventoryItem -ResourceType "launchtemplateversion" -LiteralPath "XDHyp:\HostingUnits\aws" -MaxRecords 200 -Template "ami-015xxxxxxxxx" -Warn $true).AdditionalData
<!--NeedCopy-->

Onde ir a seguir

Mais informações